@@ -241,6 +241,12 @@ class Form(SecuredController):
         buttons.i18n = not editable and mode == 'form'
 
         target = getattr(cherrypy.request, '_terp_view_target', None)
+        
+        show_header = target != 'new'
+        if not int(cherrypy.request.params.get('_terp_header_footer', 1)):
+            show_header = False
+        cherrypy.request.show_header_footer = show_header
+            
         buttons.toolbar = target != 'new' and not form.is_dashboard
 
         if cache.can_write('ir.ui.view'):
@@ -256,12 +262,12 @@ class Form(SecuredController):
             pager = tw.pager.Pager(id=form.screen.id, ids=form.screen.ids, offset=form.screen.offset,
                                    limit=form.screen.limit, count=form.screen.count, view_type=params.view_type)
 
-        return dict(form=form, pager=pager, buttons=buttons, links=links, path=self.path, show_header_footer=target!='new')
+        return dict(form=form, pager=pager, buttons=buttons, links=links, path=self.path, show_header_footer=show_header)
 
     @profile("form.edit", log=['model', 'id'])
     @expose()
     def edit(self, model, id=False, ids=None, view_ids=None, view_mode=['form', 'tree'],
-             source=None, domain=[], context={}, offset=0, limit=20, count=0, search_domain=None):
+             source=None, domain=[], context={}, offset=0, limit=20, count=0, search_domain=None, **kw):
 
         params, data = TinyDict.split({'_terp_model': model,
                                        '_terp_id' : id,
@@ -278,6 +284,8 @@ class Form(SecuredController):
 
         params.editable = True
         params.view_type = 'form'
+        
+        cherrypy.request._terp_view_target = kw.get('target')
 
         if params.view_mode and 'form' not in params.view_mode:
             params.view_type = params.view_mode[-1]
@@ -299,7 +307,7 @@ class Form(SecuredController):
 
     @expose()
     def view(self, model, id, ids=None, view_ids=None, view_mode=['form', 'tree'],
-            source=None, domain=[], context={}, offset=0, limit=20, count=0, search_domain=None):
+            source=None, domain=[], context={}, offset=0, limit=20, count=0, search_domain=None, **kw):
         params, data = TinyDict.split({'_terp_model': model,
                                        '_terp_id' : id,
                                        '_terp_ids' : ids,
@@ -315,6 +323,8 @@ class Form(SecuredController):
 
         params.editable = False
         params.view_type = 'form'
+        
+        cherrypy.request._terp_view_target = kw.get('target')
 
         if params.view_mode and 'form' not in params.view_mode:
             params.view_type = params.view_mode[-1]
@@ -418,6 +428,9 @@ class Form(SecuredController):
                 'limit': params.limit,
                 'count': params.count,
                 'search_domain': ustr(params.search_domain)}
+                
+        if not int(cherrypy.request.params.get('_terp_header_footer', 1)):
+            args['target'] = 'new'
 
         if params.editable or params.source or params.return_edit:
             raise redirect(self.path + '/edit', source=params.source, **args)
@@ -488,7 +501,7 @@ class Form(SecuredController):
 
             if action_type == 'ir.actions.wizard':
                 cherrypy.session['wizard_parent_form'] = self.path
-                cherrypy.session['wizard_parent_params'] = params
+                cherrypy.session['wizard_parent_params'] = params.parent_params or params
 
             res = actions.execute_by_id(action_id, type=action_type,
                                         model=model, id=id, ids=ids,
