@@ -72,8 +72,7 @@ class ViewForm(Form):
                              selectable=params.selectable or 2)
 
         self.sidebar = Sidebar(self.screen.model, self.screen.toolbar, self.screen.id,
-                               self.screen.view_type, self.screen.view_type != 'form',
-                               self.screen.context)
+                               self.screen.view_type, context=self.screen.context)
 
         self.is_dashboard = getattr(cherrypy.request, '_terp_dashboard', False)
 
@@ -87,7 +86,7 @@ class ViewForm(Form):
             self.screen.id = False
 
         # get the correct view title
-        self.screen.string = getattr(cherrypy.request, '_terp_view_name', self.screen.string)
+        self.screen.string = getattr(cherrypy.request, '_terp_view_name', self.screen.string) or self.screen.string
             
         # get the actual pager data
         self.limit = self.screen.limit
