@@ -544,7 +544,10 @@ class Button(TinyInputWidget):
     def __init__(self, **attrs):
         super(Button, self).__init__(**attrs)
 
-        self.states = attrs.get('states', "draft").split(',')
+        self.states = attrs.get('states')
+        if self.states:
+            self.states = self.states.split(',')
+
         self.btype = attrs.get('special', attrs.get('type', 'workflow'))
         self.icon = attrs.get('icon')
 
