@@ -153,11 +153,13 @@ class M2M(TinyInputWidget):
             selectable = 0
         else:
             selectable = 2
-            
-        try: # try to get original input values if creating validation form
-            current.ids = eval(cherrypy.request.terp_data.get(self.name))
-        except:
-            pass
+
+        # try to get original input values if creating validation form
+        if not params.filter_action:
+            try:
+                current.ids = eval(cherrypy.request.terp_data.get(self.name))
+            except:
+                pass
 
         self.screen = Screen(current, prefix=self.name, views_preloaded=view,
                              editable=False, readonly=self.editable,
